import { Module } from '@nestjs/common';
import { TypeOrmModule } from '@nestjs/typeorm';
import { Project } from '../projects/project.entity';
import { ReposResolver } from './repos.resolver';
import { ReposService } from './repos.service';
import { ConfigModule } from '@nestjs/config';
import { ProjectsModule } from '../projects/projects.module';
import { BullModule } from '@nestjs/bull';
import { LIST_LOGS_TASK, LIST_LOGS_PUB_SUB } from './repos.constants';
import { PubSub } from 'graphql-subscriptions';

@Module({
  imports: [
    TypeOrmModule.forFeature([Project]),
    ConfigModule,
    ProjectsModule,
    BullModule.registerQueue({
      name: LIST_LOGS_TASK,
    }),
  ],
  providers: [
    ReposResolver,
    ReposService,
    {
      provide: LIST_LOGS_PUB_SUB,
      useValue: new PubSub(),
    },
  ],
  exports: [ReposService],
})
export class ReposModule {}
